@@ -104,19 +104,19 @@ class Compiler:
 
     # Generate command hook
     def hook_generator(self, parms):
-        self.output.append(f'{parms["indentation"]}{watiba_ref}.add_hook(\
-            {parms["match"].group(1).strip()}, \
-            {parms["match"].group(2).strip()}, \
-            {parms["match"].group(3).strip()}, \
-            True)')
+        self.output.append(f'{parms["indentation"]}{watiba_ref}.add_hook('
+            f'{parms["match"].group(1).strip()},' 
+            f'{parms["match"].group(2).strip()},' 
+            f'{parms["match"].group(3).strip()},' 
+            'True')
     
     # Generate command non-recursive hook
     def hook_nr_generator(self, parms):
-        self.output.append(f'{parms["indentation"]}{watiba_ref}.add_hook(\
-            {parms["match"].group(1).strip()}, \
-            {parms["match"].group(2).strip()}, \
-            {parms["match"].group(3).strip()}, \
-            False)')
+        self.output.append(f'{parms["indentation"]}{watiba_ref}.add_hook('
+            f'{parms["match"].group(1).strip()},' 
+            f'{parms["match"].group(2).strip()},' 
+            f'{parms["match"].group(3).strip()},' 
+            'False')
     
     # Generate removal of command hooks
     def remove_hooks_generator(self, parms):
