@@ -155,6 +155,7 @@ class Watiba(Exception):
         # Loop through the hooks and run them.  Also track ones that fail (i.e. report a False return code)
         for command_regex, functions in self.hooks.items():
 
+            # Avoid a loop on this command pattern
             if self.hook_flags[command_regex]["recursive"] == False and self.hook_mode == True:
                 continue
 
@@ -168,9 +169,15 @@ class Watiba(Exception):
                 # If the hook fails track it, but keep going with the other hooks
                 for func, parms in functions.items():
 
+                    # Indicate we're in a hook
+                    self.hook_mode = True
+
                     # Call the hook.  The hook must return True if succeeded, False if failed
                     rc = func(mat, parms)
 
+                    # Indicate we're no longer in a hook
+                    self.hook_mode = False
+
                     # If caller's hook didn't return a bool value, then it is marked as failed
                     rc = False if type(rc) != bool else rc
 
